@@ -1,5 +1,5 @@
 /* This file is part of Metaproxy.
-   Copyright (C) 2005-2013 Index Data
+   Copyright (C) Index Data
 
 Metaproxy is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -27,7 +27,7 @@ void mp::filter::Base::start() const
 {
 }
 
-void mp::filter::Base::stop() const
+void mp::filter::Base::stop(int signo) const
 {
 }
 
