@@ -39,7 +39,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include <yaz/malloc_info.h>
 #include "gduutil.hpp"
 #include <signal.h>
-
+#include <stdlib.h>
 #include <iostream>
 
 namespace mp = metaproxy_1;
@@ -222,8 +222,8 @@ void yf::FrontendNet::ThreadPoolPackage::result(const char *t_info)
 
     if (gdu->get())
     {
-	int len;
-	m_assoc_child->send_GDU(gdu->get(), &len);
+        int len;
+        m_assoc_child->send_GDU(gdu->get(), &len);
 
         yaz_timing_stop(timer);
         double duration = yaz_timing_get_real(timer);
@@ -349,14 +349,7 @@ yazpp_1::IPDU_Observer *yf::FrontendNet::ZAssocChild::sessionNotify(
 
 yf::FrontendNet::ZAssocChild::~ZAssocChild()
 {
-    int d = m_p->m_peerStat.remove(m_peer);
-    if (m_p->m_msg_config.length())
-    {
-        std::ostringstream os;
-        os  << m_p->m_msg_config << " "
-            << m_peer << " closing cnt=" << d;
-        yaz_log(YLOG_LOG, "%s", os.str().c_str());
-    }
+    m_p->m_peerStat.remove(m_peer);
 }
 
 void yf::FrontendNet::ZAssocChild::report(Z_HTTP_Request *hreq)
@@ -509,7 +502,7 @@ void yf::FrontendNet::ZAssocChild::failNotify()
     {
         if (m_no_requests == 0)
             delete this;
-	return;
+        return;
     }
     m_no_requests++;
 
@@ -740,9 +733,9 @@ void yf::FrontendNet::process(mp::Package &package) const
 
     for (i = 0; i<m_p->m_ports.size(); i++)
     {
-	m_p->az[i]->set_package(&package);
-	m_p->az[i]->set_thread_pool(
-            tp);
+        yaz_log(YLOG_LOG, "listening on %s", m_p->m_ports[i].port.c_str());
+        m_p->az[i]->set_package(&package);
+        m_p->az[i]->set_thread_pool(tp);
     }
     while (m_p->mySocketManager.processEvent() > 0)
     {
@@ -778,8 +771,8 @@ void yf::FrontendNet::process(mp::Package &package) const
         int no = m_p->mySocketManager.getNumberOfObservers();
         if (no <= 1)
             break;
-	if (tt && tt->timeout())
-	    break;
+        if (tt && tt->timeout())
+            break;
     }
     delete tp;
     delete tt;
