@@ -1,5 +1,5 @@
 /* This file is part of Metaproxy.
-   Copyright (C) 2005-2013 Index Data
+   Copyright (C) Index Data
 
 Metaproxy is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -58,12 +58,12 @@ void mp::RouterChain::start()
         (*it)->start();
 }
 
-void mp::RouterChain::stop()
+void mp::RouterChain::stop(int signo)
 {
     std::list<const filter::Base *>::const_iterator it;
 
     for (it = m_p->m_filter_list.begin(); it != m_p->m_filter_list.end(); it++)
-        (*it)->stop();
+        (*it)->stop(signo);
 }
 
 const mp::filter::Base *mp::RouterChain::Pos::move(const char *route)
