@@ -26,9 +26,9 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include "pipe.hpp"
 #include "thread_pool_observer.hpp"
 
-#define BOOST_AUTO_TEST_MAIN
+#define BOOST_TEST_MAIN
 #define BOOST_TEST_DYN_LINK
-#include <boost/test/auto_unit_test.hpp>
+#include <boost/test/unit_test.hpp>
 
 using namespace boost::unit_test;
 using namespace yazpp_1;
